# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that manages the Station's graphic user
interface.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gobject import GObject, SIGNAL_RUN_LAST, TYPE_NONE, TYPE_PYOBJECT
from gobject import TYPE_BOOLEAN, TYPE_STRING

class Manager(GObject):
	"""
	This class manages the stations graphic user interface components
	and allows them to communicate with each other.
	"""

	__gsignals__ = {
		"destroy": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"show-window": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"showed-window": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"treeview-sensitivity": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_BOOLEAN,)),
		"treeview-changed": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_PYOBJECT,)),
		"delete-selections": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"station-edited": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_STRING,)),
		"genre-changed": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_STRING,)),
	}

	def __init__(self, trigger, player):
		"""
		Initialize object.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.

		@param trigger: Reference to the Trigger object.
		@type trigger: A Trigger object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		GObject.__init__(self)
		self.__init_attributes(trigger, player)
		from Updater import Updater
		Updater(self)
		from Window import Window
		Window(self, player)
		from AddButton import AddButton
		AddButton(self, player)
		from EditButton import EditButton
		EditButton(self, player)
		from RemoveButton import RemoveButton
		RemoveButton(self, player)
		from TreeView import TreeView
		TreeView(self, player)
		from ComboBox import ComboBox
		ComboBox(self, player)
		self.__signal_id_1 = trigger.connect("destroy", self.__destroy_cb)

	def __init_attributes(self, trigger, player):
		"""
		Initialize data attributes.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.

		@param trigger: Reference to the Trigger object.
		@type trigger: A Trigger object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		self.__trigger = trigger
		self.__player = player
		self.__signal_id_1 = None
		from os.path import join, split
		cwd = split(globals()["__file__"])[0]
		glade_file = join(cwd, "Stations.glade")
		from gtk.glade import XML
		self.__glade = XML(glade_file, domain="striim")
		return

	def __get_glade(self):
		return self.__glade

	glade = property(__get_glade)

	def show_window(self):
		"""
		Show Stations window.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.
		"""
		self.emit("show-window")
		return

	def __destroy_cb(self, trigger):
		"""
		Handles callback when the "destroy" signal is emitted.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.

		@param trigger: Reference to the Trigger object.
		@type trigger: A Trigger object.
		"""
		self.emit("destroy")
		from Striim.utils import delete_attributes, disconnect_signal
		disconnect_signal(self.__signal_id_1, self)
		delete_attributes(self)
		del self
		self = None
		return
